@@ -4,9 +4,9 @@
 Module      : HsLua.Class.Invokable
 Copyright   : © 2007–2012 Gracjan Polak,
                 2012–2016 Ömer Sinan Ağacan,
-                2017-2022 Albert Krewinkel
+                2017-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 Stability   : beta
 Portability : FlexibleInstances, ForeignFunctionInterface, ScopedTypeVariables
 
